==> 0.0.8.tar.gz: android/src/main/kotlin/com/aibirch/fake_downloader/FakeDownloaderPlugin.kt <==
package com.aibirch.fake_downloader

import android.content.Intent
import android.content.pm.ApplicationInfo
import android.content.pm.PackageManager
import android.graphics.Bitmap
import android.graphics.BitmapFactory
import android.net.Uri
import android.os.Environment
import io.flutter.util.PathUtils
import io.flutter.embedding.engine.plugins
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.PluginRegistry.Registrar
import java.io.File
import java.io.FileOutputStream
import java.io.IOException

class FakeDownloaderPlugin(private val registrar: Registrar): MethodCallHandler, FlutterPlugin{


  override fun onAttachedToEngine(@NonNull binding: FlutterPluginBinding?) {
    // TODO: your plugin is now attached to a Flutter experience.
  }

  @Override
  override fun onDetachedFromEngine(@NonNull binding: FlutterPluginBinding?) {
    // TODO: your plugin is no longer attached to a Flutter experience.
  }

  companion object {
    @JvmStatic
    fun registerWith(registrar: Registrar) {
      val channel = MethodChannel(registrar.messenger(), "downloader")
      channel.setMethodCallHandler(FakeDownloaderPlugin(registrar))
    }
  }

  override fun onMethodCall(call: MethodCall, result: Result): Unit {
    when {
      call.method == "saveImageToGallery" -> {
        val image = call.argument<ByteArray>("imageBytes") ?: return
        val quality = call.argument<Int>("quality") ?: return
        val name = call.argument<String>("name")

        result.success(saveImageToGallery(BitmapFactory.decodeByteArray(image,0,image.size), quality, name))
      }
      call.method == "saveFileToGallery" -> {
        val path = call.argument<String>("file") ?: return
        result.success(saveFileToGallery(path))
      }
      else -> result.notImplemented()
    }

  }

  private fun generateFile(extension: String = "", name: String? = null): File {
    val storePath =  Environment.getExternalStorageDirectory().absolutePath + File.separator + Environment.DIRECTORY_PICTURES
    val appDir = File(storePath)
    if (!appDir.exists()) {
      appDir.mkdir()
    }
    var fileName = name?:System.currentTimeMillis().toString()
    if (extension.isNotEmpty()) {
      fileName += (".$extension")
    }
    return File(appDir, fileName)
  }

  private fun saveImageToGallery(bmp: Bitmap, quality: Int, name: String?): HashMap<String, Any?> {
    val context = registrar.activeContext().applicationContext
    val file = generateFile("jpg", name = name)
    return try {
      val fos = FileOutputStream(file)
      bmp.compress(Bitmap.CompressFormat.JPEG, quality, fos)
      fos.flush()
      fos.close()
      val uri = Uri.fromFile(file)
      context.sendBroadcast(Intent(Intent.ACTION_MEDIA_SCANNER_SCAN_FILE, uri))
      bmp.recycle()
      SaveResultModel(uri.toString().isNotEmpty(), uri.toString(), null).toHashMap()
    } catch (e: IOException) {
      SaveResultModel(false, null, e.toString()).toHashMap()
    }
  }

  private fun saveFileToGallery(filePath: String): HashMap<String, Any?> {
    val context = registrar.activeContext().applicationContext
    return try {
      val originalFile = File(filePath)
      val file = generateFile(originalFile.extension)
      originalFile.copyTo(file)

      val uri = Uri.fromFile(file)
      context.sendBroadcast(Intent(Intent.ACTION_MEDIA_SCANNER_SCAN_FILE, uri))
      SaveResultModel(uri.toString().isNotEmpty(), uri.toString(), null).toHashMap()
    } catch (e: IOException) {
      SaveResultModel(false, null, e.toString()).toHashMap()
    }
  }

  private fun getApplicationName(): String {
    val context = registrar.activeContext().applicationContext
    var ai: ApplicationInfo? = null
    try {
      ai = context.packageManager.getApplicationInfo(context.packageName, 0)
    } catch (e: PackageManager.NameNotFoundException) {
    }
    var appName: String
    appName = if (ai != null) {
      val charSequence = context.packageManager.getApplicationLabel(ai)
      StringBuilder(charSequence.length).append(charSequence).toString()
    } else {
      "downloader"
    }
    return  appName
  }


}

class SaveResultModel (var isSuccess: Boolean,
                       var filePath: String? = null,
                       var errorMessage: String? = null) {
  fun toHashMap(): HashMap<String, Any?> {
    val hashMap = HashMap<String, Any?>()
    hashMap["isSuccess"] = isSuccess
    hashMap["filePath"] = filePath
    hashMap["errorMessage"] = errorMessage
    return hashMap
  }
}

==> 0.0.10.tar.gz: android/src/main/kotlin/com/aibirch/fake_downloader/FakeDownloaderPlugin.kt <==
package com.aibirch.fake_downloader

import android.content.Intent
import android.content.pm.ApplicationInfo
import android.content.pm.PackageManager
import android.graphics.Bitmap
import android.graphics.BitmapFactory
import android.net.Uri
import android.os.Environment
import io.flutter.util.PathUtils
import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.plugin.common.BinaryMessenger;
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.PluginRegistry.Registrar
import java.io.File
import java.io.FileOutputStream
import java.io.IOException

class FakeDownloaderPlugin(private val registrar: Registrar): MethodCallHandler, FlutterPlugin{

  private lateinit var channel : MethodChannel

  override fun onAttachedToEngine(@NonNull binding: FlutterPluginBinding?) {
    channel = MethodChannel(binding.messenger(), "downloader")
    channel.setMethodCallHandler(FakeDownloaderPlugin(binding))
  }

  @Override
  override fun onDetachedFromEngine(@NonNull binding: FlutterPluginBinding?) {
    // TODO: your plugin is no longer attached to a Flutter experience.
  }

  companion object {
    @JvmStatic
    fun registerWith(registrar: Registrar) {
      val channel = MethodChannel(registrar.messenger(), "downloader")
      channel.setMethodCallHandler(FakeDownloaderPlugin(registrar))
    }
  }

  override fun onMethodCall(call: MethodCall, result: Result): Unit {
    when {
      call.method == "saveImageToGallery" -> {
        val image = call.argument<ByteArray>("imageBytes") ?: return
        val quality = call.argument<Int>("quality") ?: return
        val name = call.argument<String>("name")

        result.success(saveImageToGallery(BitmapFactory.decodeByteArray(image,0,image.size), quality, name))
      }
      call.method == "saveFileToGallery" -> {
        val path = call.argument<String>("file") ?: return
        result.success(saveFileToGallery(path))
      }
      else -> result.notImplemented()
    }

  }

  private fun generateFile(extension: String = "", name: String? = null): File {
    val storePath =  Environment.getExternalStorageDirectory().absolutePath + File.separator + Environment.DIRECTORY_PICTURES
    val appDir = File(storePath)
    if (!appDir.exists()) {
      appDir.mkdir()
    }
    var fileName = name?:System.currentTimeMillis().toString()
    if (extension.isNotEmpty()) {
      fileName += (".$extension")
    }
    return File(appDir, fileName)
  }

  private fun saveImageToGallery(bmp: Bitmap, quality: Int, name: String?): HashMap<String, Any?> {
    val context = registrar.activeContext().applicationContext
    val file = generateFile("jpg", name = name)
    return try {
      val fos = FileOutputStream(file)
      bmp.compress(Bitmap.CompressFormat.JPEG, quality, fos)
      fos.flush()
      fos.close()
      val uri = Uri.fromFile(file)
      context.sendBroadcast(Intent(Intent.ACTION_MEDIA_SCANNER_SCAN_FILE, uri))
      bmp.recycle()
      SaveResultModel(uri.toString().isNotEmpty(), uri.toString(), null).toHashMap()
    } catch (e: IOException) {
      SaveResultModel(false, null, e.toString()).toHashMap()
    }
  }

  private fun saveFileToGallery(filePath: String): HashMap<String, Any?> {
    val context = registrar.activeContext().applicationContext
    return try {
      val originalFile = File(filePath)
      val file = generateFile(originalFile.extension)
      originalFile.copyTo(file)

      val uri = Uri.fromFile(file)
      context.sendBroadcast(Intent(Intent.ACTION_MEDIA_SCANNER_SCAN_FILE, uri))
      SaveResultModel(uri.toString().isNotEmpty(), uri.toString(), null).toHashMap()
    } catch (e: IOException) {
      SaveResultModel(false, null, e.toString()).toHashMap()
    }
  }

  private fun getApplicationName(): String {
    val context = registrar.activeContext().applicationContext
    var ai: ApplicationInfo? = null
    try {
      ai = context.packageManager.getApplicationInfo(context.packageName, 0)
    } catch (e: PackageManager.NameNotFoundException) {
    }
    var appName: String
    appName = if (ai != null) {
      val charSequence = context.packageManager.getApplicationLabel(ai)
      StringBuilder(charSequence.length).append(charSequence).toString()
    } else {
      "downloader"
    }
    return  appName
  }


}

class SaveResultModel (var isSuccess: Boolean,
                       var filePath: String? = null,
                       var errorMessage: String? = null) {
  fun toHashMap(): HashMap<String, Any?> {
    val hashMap = HashMap<String, Any?>()
    hashMap["isSuccess"] = isSuccess
    hashMap["filePath"] = filePath
    hashMap["errorMessage"] = errorMessage
    return hashMap
  }
}
